# Bulker

Bulker builds multi-container computing environments that are both **modular** and **interactive**. 

For details, see the [bulker documentation](http://docs.bulker.io). You can find and share manifests at [bulker hub](http://hub.bulker.io).
